## Arches for Science 2.0.0 Release Notes


### Bug Fixes and Enhancements

- Upgrades Arches for Science to work with the latest Arches 7.6.x release [#1570](https://github.com/archesproject/arches-for-science/pull/1570)
- Automatically delete part tiles when analysis and sample areas are deleted [#1588](https://github.com/archesproject/arches-for-science/pull/1588)
- Ensures TileModel queries are safe for Arches v8 [#1565](https://github.com/archesproject/arches-for-science/pull/1565)

### Dependency changes:

```
Python:
    Upgraded:
        None
JavaScript:
    Upgraded:
        none
```

### Breaking Changes
Due to changes in how projects and apps are configured in the final release of Arches 7.6.3, there are significant project alterations that necessary to run this version of Arches for Science.

### Upgrading Arches for Science 
1. Start by upgrading your project to run using [Arches 7.6](https://github.com/archesproject/arches/blob/dev/7.6.x/releases/7.6.0.md#upgrading-arches). 

2. Update arches-for-science in your project's package.json file:
    ```
    "arches_for_science": "archesproject/arches-for-science#dev/2.0.x"
    ```

3. Add arches_for_science to your project's dependencies in your pyproject.toml file:
    ```
    "arches_for_science>=2.0.0,<2.1.0"
    ```

4. Upgrade to Arches for Science 2.0.0
    ```
    pip install --upgrade arches_for_science==2.0.0
    ```


